function Main_ray_model_paper
clear all
close all

P_T = .001;                                                 % Transmit power
lambda = .011;                                              % Wavelength

[R ang]= grid_angles;                                       % Distance information from the receiver grid

G_R_Az = {}; G_T_Az = {}; Gain_select = {};

%% For flat reflectors
[Gain_select{1} Gain_select{2} Gain_selectc1 Gain_selectc2] = Gain_selection(8);        % .84x.84 reflector's gain
[Gain_select{3} Gain_select{4} Gain_selectc1 Gain_selectc2] = Gain_selection(6);        % .61x.61 reflector's gain
[Gain_select{5} Gain_select{6} Gain_selectc1 Gain_selectc2] = Gain_selection(4);        % .30x.30 reflector's gain

G_R_Az{1} = 10.^(Gain_select{1}./10);
G_T_Az{1} = 10.^(Gain_select{2}./10);

G_R_Az{2} = 10.^(Gain_select{3}./10);
G_T_Az{2} = 10.^(Gain_select{4}./10);

G_R_Az{3} = 10.^(Gain_select{5}./10);
G_T_Az{3} = 10.^(Gain_select{6}./10);

Num1 = P_T.*G_T_Az{1}.*G_R_Az{1}.*lambda.^2;
Num2 = P_T.*G_T_Az{2}.*G_R_Az{2}.*lambda.^2;
Num3 = P_T.*G_T_Az{3}.*G_R_Az{3}.*lambda.^2;

Denom = (4*pi*(4+R)).^2;

P_R1 = Num1./Denom;
P_R2 = Num2./Denom;
P_R3 = Num3./Denom;

P_S = 10^-10;                                                                   % Power when there is no reflector (from measurements)

P_R1 = P_R1 + P_S;                                                              % Conversion to dBm
P_R1 = 10*log10(P_R1./.001);

P_R2 = P_R2 + P_S;
P_R2 = 10*log10(P_R2./.001);

P_R3 = P_R3 + P_S;
P_R3 = 10*log10(P_R3./.001);


% Plotting
fig=figure
imagesc((1:5)*0.3, (0:2:50)*.3, fliplr(P_R1.'))
colormap(jet(1000))
c=colorbar
xlabel({'x [m]'});
ylabel('y [m]');
title('Ray Modeling')
ax = gca;
caxis([-87.56 -41.4])
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
set(gca,'Fontsize',4)
set(gcf, 'Position',  [100, 40, 215, 300])

fig=figure
imagesc((1:5)*0.3, (0:2:50)*.3, fliplr(P_R2.'))
colormap(jet(1000))
c=colorbar
xlabel({'x [m]'});
ylabel('y [m]');
title('Ray Modeling')
ax = gca;
caxis([-87.56 -41.4])
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
set(gca,'Fontsize',4)
set(gcf, 'Position',  [100, 40, 215, 300])

fig=figure
imagesc((1:5)*0.3, (0:2:50)*.3, fliplr(P_R3.'))
colormap(jet(1000))
c=colorbar
xlabel({'x [m]'});
ylabel('y [m]');
title('Ray Modeling')
ax = gca;
caxis([-87.56 -41.4])
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
set(gca,'Fontsize',4)
set(gcf, 'Position',  [100, 40, 215, 300])

%% For cylinder and sphere reflectors

G_R_Az_c = 10.^(Gain_selectc1./10);
G_T_Az_c = 10.^(Gain_selectc2./10);

Num_c = P_T.*G_T_Az_c.*G_R_Az_c.*lambda.^2;

P_R_c = Num_c./Denom;

P_R_c = P_R_c + P_S;
P_R_c = 10*log10(P_R_c./.001);

%% CDF of received power
% CDF plots for flat sheet reflectors
col = {'b','g','m','c','k'};
figure

hold on
temp = reshape(P_R3,[size(P_R3,1)*size(P_R3,2),1]);
h1 = cdfplot(temp(1:1:end))
temp = reshape(P_R2,[size(P_R2,1)*size(P_R2,2),1]);
h2 = cdfplot(temp(1:1:end))
temp = reshape(P_R1,[size(P_R1,1)*size(P_R1,2),1]);
h3 = cdfplot(temp(1:1:end))


fig=figure
hold on
line_fewer_markers(h1.XData, h1.YData, 10, 'm- +', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{1})
line_fewer_markers(h2.XData, h2.YData, 10, 'm- >', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{2})
line_fewer_markers(h3.XData, h3.YData, 10, 'm- s', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{3})

xlabel({'Received power (dBm)'})
ylabel('CDF')
legend('Ray model .30mx.30m reflector', 'Ray model .61mx.61m reflector','Ray model .84mx.84m reflector');
legend(gca,'location','NorthWest')
legend(gca,'location','NorthWest')
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');
set(gca,'Fontsize',14)
xlim([-97 -40])
set(gcf, 'Position',  [200, 50, 800, 600])
yticks([0 0.2 0.4 0.6 0.8 1])
xticks([-90 -80 -70 -60 -50 -40])
